@@ -89,15 +89,20 @@ def opretMappe(self, folderName, folderComment, folderId):
     else:
         raise Exception("Oprettelsen af mappen var ikke succesfuld")
 
-def dokumentHent(self, dokumentId):
+def dokumentHent(self, dokumentId, doctype):
     url = f"https://www.lectio.dk/lectio/{self.skoleId}/dokumenthent.aspx?documentid={dokumentId}"
+    if doctype: url += f"&doctype={doctype}"
     resp = self.session.get(url)
     if resp.url != url:
         raise Exception("lectio-cookie udløbet")
 
-    return resp.content
+    return {
+        "content": resp.content,
+        "content-type": resp.headers["content-type"],
+        "content-disposition": resp.headers["content-disposition"],
+    }
 
-def dokumentUpload(self, fileName, folderId, contentType, content, fileComment, public, documentId):
+def dokumentUpload(self, fileName, folderId, contentType, content, fileComment, public, documentId): # Todo: Omskriv
     urlDokumentRediger = f"https://www.lectio.dk/lectio/{self.skoleId}/dokumentrediger.aspx?" + (f"dokumentid={documentId}" if documentId else f"folderid={folderId}")
     resp = self.session.get(urlDokumentRediger)
     if resp.url != urlDokumentRediger:
