@@ -1,36 +1,45 @@
-"""
-TODO:
-  * Gør elev og lærer id til id men hvor at elev id har et S foran (Eks: S123456789) og lærer har et T foran (Eks: T12345678)
-"""
-
 from .imports import *
-from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _eksamener, _studieretning, _spørgeskema, _termin
+from . import _auth, _lektier, _skema, _modul, _opgaver, _beskeder, _informationer, _filer, _fravær, _dokumenter, _forside, _ledigeLokaler, _karakterer, _eksamener, _studieretning, _spørgeskema, _termin, _studieplan
 
 class sdk:
-    def __init__(self, brugernavn, adgangskode, skoleId, base64Cookie=None):
+    def __init__(self, brugernavn=None, adgangskode=None, skoleId=None, base64Cookie=None, userId=None, QrId=None):
         self.session = requests.session()
 
-        if base64Cookie == None:
+        if brugernavn != None and adgangskode != None and skoleId != None:
             self.brugernavn = brugernavn
             self.adgangskode = adgangskode
             self.skoleId = skoleId
 
             self.login()
-        else:
+        elif base64Cookie != None:
             cookie = json.loads(base64.b64decode(base64Cookie))
             for _cookie in cookie:
                 self.session.cookies.set(_cookie["name"], _cookie["value"], domain=_cookie["for"])
 
             self.skoleId = self.session.cookies["LastLoginExamno"]
             self.elevId = self.session.cookies["LastLoginElevId"]
+        elif userId != None and QrId != None and skoleId != None:
+            self.skoleId = skoleId
 
-        self.session.headers.update({"content-type": "application/x-www-form-urlencoded"})
+            self.qrLogin(userId, QrId)
+        else:
+            raise Exception("Der blev ikke angivet nok parameter til at kunne logge ind.")
+
+
+        self.session.cookies.set("isloggedin3", "Y", domain="www.lectio.dk")
+        self.session.headers.update({
+            "content-type": "application/x-www-form-urlencoded",
+            "referer": f"https://www.lectio.dk/lectio/{self.skoleId}/forside.aspx",
+        })
     def login(self):
         return _auth.login(self)
 
     def base64Cookie(self):
         return _auth.base64Cookie(self)
 
+    def qrLogin(self, userId, QrId):
+        return _auth.qrLogin(self, userId, QrId)
+
     def lektier(self):
         return _lektier.lektier(self)
 
@@ -40,6 +49,9 @@ class sdk:
     def modul(self, absid):
         return _modul.modul(self, absid)
 
+    def modulHtml(self, absid):
+        return _modul.modulHtml(self, absid)
+
     def opgave(self, exerciseid):
         return _opgaver.opgave(self, exerciseid)
     def opgaver(self):
@@ -108,5 +120,23 @@ class sdk:
     def besvarSpørgeskema(self, id, besvarelser):
         return _spørgeskema.besvarSpørgeskema(self, id, besvarelser)
 
-    def lokaleDagsorden(self):
-        return _ledigeLokaler.lokaleDagsorden(self)
\ No newline at end of file
+    def lokaleDagsorden(self, kunAktuelAfdeling=True):
+        return _ledigeLokaler.lokaleDagsorden(self, kunAktuelAfdeling)
+
+    def studieplan(self):
+        return _studieplan.studieplan(self)
+
+    def forløb(self, id):
+        return _studieplan.forløb(self, id)
+
+    def dokumentUpload(self, fileName, folderId, contentType, content, fileComment="", public=False, documentId=None):
+        return _dokumenter.dokumentUpload(self, fileName, folderId, contentType, content, fileComment, public, documentId)
+
+    def dokumentHent(self, dokumentId, doctype=None):
+        return _dokumenter.dokumentHent(self, dokumentId, doctype)
+
+    def fåHoldMedlemmer(self, id):
+        return _informationer.fåHoldMedlemmer(self, id)
+
+    def afleverOpgave(self, exerciseid, fileName, fileContentType, fileContent="", note=None):
+        return _opgaver.afleverOpgave(self, exerciseid, fileName, fileContentType, fileContent, note)
\ No newline at end of file
